=====
maria
=====

.. image:: https://img.shields.io/travis/tomachito/maria.svg
        :target: https://travis-ci.org/tomachito/maria

.. image:: https://img.shields.io/pypi/v/maria.svg
        :target: https://pypi.python.org/pypi/maria


Atmospheric simulation

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://tomachito.github.io/maria.

Features
--------

* TODO
